import { __assign } from "tslib";
import { isObject } from 'lodash';
import { addDefaultArgs, getArgsString } from './utils';
import { FIREBASE_TOOLS_BASE_COMMAND, FIREBASE_EXTRA_PATH } from './constants';
/**
 * Build Command to run Firestore action. Commands call either firebase-extra
 * (in bin/firebaseExtra.js) or firebase-tools directly. FIREBASE_TOKEN must
 * exist in environment if running commands that call firebase-tools.
 * @param Cypress - Cypress object
 * @param action - action to run on Firstore (i.e. "add", "delete")
 * @param actionPath - Firestore path where action should be run
 * @param fixturePathOrData - Path to fixture. If object is passed,
 * it is used as options.
 * @param [opts={}] - Options object
 * @param opts.args - Extra arguments to be passed with command
 * @param opts.token - Firebase CI token to pass as the token argument
 * @returns Command string to be used with cy.exec
 */
export default function buildFirestoreCommand(Cypress, action, actionPath, fixturePathOrData, opts) {
    var options = isObject(fixturePathOrData) && !opts ? fixturePathOrData : opts || {};
    var _a = options.args, args = _a === void 0 ? [] : _a, recursive = options.recursive;
    var argsWithDefaults = addDefaultArgs(Cypress, args, __assign(__assign({}, options), { disableYes: true }));
    var commandStr = FIREBASE_EXTRA_PATH + " firestore " + action + " " + actionPath;
    switch (action) {
        case 'delete': {
            var deleteArgsWithDefaults = addDefaultArgs(Cypress, args, options);
            // Add -r to args string (recursive) if recursive option is true otherwise specify shallow
            var finalDeleteArgs = deleteArgsWithDefaults.concat(recursive ? '-r' : '--shallow');
            var deleteArgsStr = getArgsString(finalDeleteArgs);
            return FIREBASE_TOOLS_BASE_COMMAND + " firestore:" + action + " " + actionPath + deleteArgsStr;
        }
        case 'get': {
            return FIREBASE_EXTRA_PATH + " firestore " + action + " " + actionPath;
        }
        default: {
            var argsStr = getArgsString(argsWithDefaults);
            if (!isObject(fixturePathOrData)) {
                return commandStr + " " + fixturePathOrData + argsStr;
            }
            return commandStr + " '" + JSON.stringify(fixturePathOrData) + "'" + argsStr;
        }
    }
}
