import { FixtureData } from './buildFirestoreCommand';
/**
 * Action for Real Time Database
 */
export declare type RTDBAction = 'remove' | 'set' | 'update' | 'delete' | 'get';
/**
 * Options for callRtdb commands
 */
export interface RTDBCommandOptions {
    /**
     * Whether or not to include meta data
     */
    withMeta?: boolean;
    /**
     * Extra arguments
     */
    args?: string[];
    /**
     * CI Token
     */
    token?: string;
    /**
     * Limit to the last <num> results. If true is passed
     * than query is limited to last 1 item.
     */
    limitToLast?: boolean | number;
    /**
     * Limit to the first <num> results. If true is passed
     * than query is limited to last 1 item.
     */
    limitToFirst?: boolean | number;
    /**
     * Select a child key by which to order results
     */
    orderByChild?: string;
    /**
     * Order by key name
     */
    orderByKey?: boolean;
    /**
     * Order by primitive value
     */
    orderByValue?: boolean;
    /**
     * Start results at <val> (based on specified ordering)
     */
    startAt?: any;
    /**
     * End results at <val> (based on specified ordering)
     */
    endAt?: any;
    /**
     * Restrict results to <val> (based on specified ordering)
     */
    equalTo?: any;
    /**
     * Use the database <instance>.firebaseio.com (if omitted, use default database instance)
     */
    instance?: string;
}
/**
 * Build Command to run Real Time Database action. All commands call
 * firebase-tools directly, so FIREBASE_TOKEN must exist in environment.
 * @param Cypress - Cypress object
 * @param action - action to run on Firstore (i.e. "add", "delete")
 * @param actionPath - Firestore path where action should be run
 * @param fixturePath - Path to fixture. If object is passed,
 * it is used as options.
 * @param [opts={}] - Options object
 * @param opts.args - Extra arguments to be passed with command
 * @returns Command string to be used with cy.exec
 */
export default function buildRtdbCommand(Cypress: any, action: RTDBAction, actionPath: string, fixturePath?: FixtureData | RTDBCommandOptions | any, opts?: RTDBCommandOptions): string;
