/**
 * Get settings from firebaserc file
 * @param filePath - Path for file
 * @returns Firebase settings object
 */
export declare function readJsonFile(filePath: string): any;
/**
 * Get environment slug
 * @returns Environment slug
 */
export declare function getEnvironmentSlug(): string;
/**
 * Get prefix for current environment based on environment vars available
 * within CI. Falls back to staging (i.e. STAGE)
 * @param envName - Environment option
 * @returns Environment prefix string
 */
export declare function getEnvPrefix(envName?: string): string;
/**
 * Create a variable name string with environment prefix (i.e. STAGE_SERVICE_ACCOUNT)
 * @param varNameRoot - Root of environment variable name
 * @param envName - Environment option
 * @returns Environment var name with prefix
 */
export declare function withEnvPrefix(varNameRoot: string, envName?: string): string;
/**
 * Get path to cypress config file
 * @returns Path to cypress config file
 */
export declare function getCypressConfigPath(): string;
/**
 * Get environment variable based on the current CI environment
 * @param varNameRoot - variable name without the environment prefix
 * @param envName - Environment option
 * @returns Value of the environment variable
 * @example
 * envVarBasedOnCIEnv('FIREBASE_PROJECT_ID')
 * // => 'fireadmin-stage' (value of 'STAGE_FIREBASE_PROJECT_ID' environment var)
 */
export declare function envVarBasedOnCIEnv(varNameRoot: string, envName?: string): any;
interface ServiceAccount {
    type: string;
    project_id: string;
    private_key_id: string;
    private_key: string;
    client_email: string;
    client_id: string;
    auth_uri: string;
    token_uri: string;
    auth_provider_x509_cert_url: string;
    client_x509_cert_url: string;
}
/**
 * Get service account from either local file or environment variables
 * @param envSlug - Environment option
 * @returns Service account object
 */
export declare function getServiceAccount(envSlug: string): ServiceAccount;
export interface RunCommandOptions {
    command: string;
    args: string[];
    pipeOutput?: boolean;
}
/**
 * Run a bash command using spawn pipeing the results to the main process
 * @param runOptions - Options for command run
 * @param runOptions.command - Command to be executed
 * @param runOptions.args - Command arguments
 * @returns Resolves with results of running the command
 * @private
 */
export declare function runCommand(runOptions: RunCommandOptions): Promise<any>;
export {};
