/**
 * Action for Firestore
 */
export declare type FirestoreAction = 'delete' | 'set' | 'update' | 'get';
/**
 * Data from loaded fixture
 */
export interface FixtureData {
    [k: string]: any;
}
/**
 * Options for building Firestore commands
 */
export interface FirestoreCommandOptions {
    /**
     * Whether or not to include createdAt and createdBy
     */
    withMeta?: boolean;
    /**
     * Extra command line arguments to add to command
     */
    args?: string[];
    /**
     * firebase-tools CI token
     */
    token?: string;
    /**
     * Whether or not to run recursive delete of collections
     * and subcollections
     */
    recursive?: boolean;
}
/**
 * Build Command to run Firestore action. Commands call either firebase-extra
 * (in bin/firebaseExtra.js) or firebase-tools directly. FIREBASE_TOKEN must
 * exist in environment if running commands that call firebase-tools.
 * @param Cypress - Cypress object
 * @param action - action to run on Firstore (i.e. "add", "delete")
 * @param actionPath - Firestore path where action should be run
 * @param fixturePathOrData - Path to fixture. If object is passed,
 * it is used as options.
 * @param [opts={}] - Options object
 * @param opts.args - Extra arguments to be passed with command
 * @param opts.token - Firebase CI token to pass as the token argument
 * @returns Command string to be used with cy.exec
 */
export default function buildFirestoreCommand(Cypress: any, action: FirestoreAction, actionPath: string, fixturePathOrData?: FixtureData | string | FirestoreCommandOptions, opts?: FirestoreCommandOptions): string;
