"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var lodash_1 = require("lodash");
var utils_1 = require("./utils");
var constants_1 = require("./constants");
/**
 * Build Command to run Firestore action. Commands call either firebase-extra
 * (in bin/firebaseExtra.js) or firebase-tools directly. FIREBASE_TOKEN must
 * exist in environment if running commands that call firebase-tools.
 * @param Cypress - Cypress object
 * @param action - action to run on Firstore (i.e. "add", "delete")
 * @param actionPath - Firestore path where action should be run
 * @param fixturePathOrData - Path to fixture. If object is passed,
 * it is used as options.
 * @param [opts={}] - Options object
 * @param opts.args - Extra arguments to be passed with command
 * @param opts.token - Firebase CI token to pass as the token argument
 * @returns Command string to be used with cy.exec
 */
function buildFirestoreCommand(Cypress, action, actionPath, fixturePathOrData, opts) {
    var options = lodash_1.isObject(fixturePathOrData) && !opts ? fixturePathOrData : opts || {};
    var _a = options.args, args = _a === void 0 ? [] : _a, recursive = options.recursive;
    var argsWithDefaults = utils_1.addDefaultArgs(Cypress, args, tslib_1.__assign(tslib_1.__assign({}, options), { disableYes: true }));
    var commandStr = constants_1.FIREBASE_EXTRA_PATH + " firestore " + action + " " + actionPath;
    switch (action) {
        case 'delete': {
            var deleteArgsWithDefaults = utils_1.addDefaultArgs(Cypress, args, options);
            // Add -r to args string (recursive) if recursive option is true otherwise specify shallow
            var finalDeleteArgs = deleteArgsWithDefaults.concat(recursive ? '-r' : '--shallow');
            var deleteArgsStr = utils_1.getArgsString(finalDeleteArgs);
            return constants_1.FIREBASE_TOOLS_BASE_COMMAND + " firestore:" + action + " " + actionPath + deleteArgsStr;
        }
        case 'get': {
            return constants_1.FIREBASE_EXTRA_PATH + " firestore " + action + " " + actionPath;
        }
        default: {
            var argsStr = utils_1.getArgsString(argsWithDefaults);
            if (!lodash_1.isObject(fixturePathOrData)) {
                return commandStr + " " + fixturePathOrData + argsStr;
            }
            return commandStr + " '" + JSON.stringify(fixturePathOrData) + "'" + argsStr;
        }
    }
}
exports.default = buildFirestoreCommand;
