export interface CypressEnvironmentOptions {
    envName?: string;
    firebaseProjectId?: string;
    [k: string]: any;
}
export interface CypressConfig {
    env?: CypressEnvironmentOptions;
    baseUrl: string;
    [k: string]: any;
}
export interface ExtendedCypressConfig {
    [k: string]: any;
    FIREBASE_PROJECT_ID?: string;
    baseUrl: string;
}
export interface ExtendWithFirebaseConfigSettings {
    localBaseUrl?: string;
    localHostPort?: string | number;
}
/**
 * Get Firebase project id using Cypress config and config
 * loaded from .firebaserc
 * @param config - Cypress config object
 * @returns Id of firbase project
 */
export declare function getFirebaseProjectIdFromConfig(config: CypressConfig): string;
/**
 * Load config for Cypress from .firebaserc.
 * @param cypressConfig - Existing Cypress config
 * @param settings - Settings
 * @returns Cypress config extended with FIREBASE_PROJECT_ID and baseUrl
 */
export default function extendWithFirebaseConfig(cypressConfig: CypressConfig, settings?: ExtendWithFirebaseConfigSettings): ExtendedCypressConfig;
